@@ -184,6 +184,10 @@ static const gchar *const author_credits[] = {
   "Ivar Smolin <okul linux ee>",
   "Jens Seidel <jensseidel users sf net>",
   "Benoît Dejean <tazforever dlfp org>",
+  "Yair Hershkovitz <yairhr gmail com>",
+  "Clytie Siddall <clytie riverland net au>",
+  "Ilkka Tuohela <hile iki fi>",
+  "Chao-Hsiung Liao <j_h_liau yahoo com tw>",
   NULL
 };
 
